@@ -3,30 +3,16 @@
 #include "crux-rc-style.h"
 #include "crux-common.h"
 #include "crux-pixmaps.h"
-#include "crux-gradient.h"
 
 #include <stdio.h>
 #include <math.h>
 #include <string.h>
 
-/* #define DEBUG 1 */
+#define DEBUG 0
 
 #define DETAIL(xx) ((detail) != 0 && strcmp (xx, detail) == 0)
 
-static GtkStyleClass *parent_style_class;
-
-typedef struct focus_change_data_struct focus_change_data;
-struct focus_change_data_struct {
-    GtkWidget *widget;
-
-    gboolean is_focused;
-    gboolean connected;
-
-    guint focus_in_signal_id;
-    guint focus_out_signal_id;
-    guint destroyed_signal_id;
-};
-
+GtkStyleClass *parent_style_class;
 
 static void
 draw_hline (GtkStyle *style,
@@ -214,14 +200,82 @@ draw_handle (GtkStyle *style,
 static inline void
 debug (const char *fmt, ...)
 {
-#ifdef DEBUG
+    if (DEBUG)
+    {
 	va_list args;
 	va_start (args, fmt);
 	vfprintf (stderr, fmt, args);
 	va_end (args);
-#endif
+    }
 }
 
+/* cairo functions */
+
+static cairo_t *
+crux_begin_paint (GdkDrawable *window, GdkRectangle *area)
+{
+	cairo_t *cr;
+
+	cr = (cairo_t*) gdk_cairo_create (window);
+
+	cairo_set_line_width (cr, 1.0);
+
+	if (area)
+	{
+		cairo_rectangle (cr, area->x, area->y, area->width, area->height);
+		cairo_clip (cr);
+		cairo_new_path (cr);
+	}
+
+	return cr;
+}
+
+static void
+crux_paint_menuitem_gradient (cairo_t * cr, GdkColor * c, gdouble x, gdouble y, gdouble width, gdouble height)
+{
+	cairo_pattern_t * crp;
+	gdouble r, g, b;
+	r = c->red / 65536.0;
+	g = c->green / 65536.0;
+	b = c->blue / 65536.0;
+	crp = cairo_pattern_create_linear (x, y, x, y + height);
+	cairo_pattern_add_color_stop_rgb (crp, 0.0, r/2.0, g/2.0, b/2.0);
+	cairo_pattern_add_color_stop_rgb (crp, 0.2, r, g, b);
+	cairo_pattern_add_color_stop_rgb (crp, 0.85, r, g, b);
+	cairo_pattern_add_color_stop_rgb (crp, 1.0, r/2.0, g/2.0, b/2.0);
+	cairo_rectangle (cr, x, y, width, height);
+	cairo_set_source (cr, crp);
+	cairo_fill (cr);
+	cairo_pattern_destroy (crp);
+}
+
+static void
+crux_paint_gradient (cairo_t * cr, GdkColor * c, GdkRectangle * rect, eazel_engine_gradient *gradient)
+{
+	gint x, y, width, height;
+	x = rect->x; y = rect->y; width = rect->width; height = rect->height;
+
+	cairo_set_line_width (cr, 0.0);
+	cairo_pattern_t * crp;
+	gdouble r, g, b;
+	r = c->red / 65536.0;
+	g = c->green / 65536.0;
+	b = c->blue / 65536.0;
+	if (gradient->direction == GRADIENT_VERTICAL)
+		crp = cairo_pattern_create_linear (x, y, x, y + height);
+	else if (gradient->direction == GRADIENT_HORIZONTAL)
+		crp = cairo_pattern_create_linear (x, y, x + width, y);
+
+	cairo_pattern_add_color_stop_rgb (crp, 0.0, r*1.1, g*1.1, b*1.1);
+	cairo_pattern_add_color_stop_rgb (crp, 1.0, r*.8, g*.8, b*.8);
+	cairo_rectangle (cr, x, y, width, height);
+	cairo_set_source (cr, crp);
+	cairo_fill (cr);
+	cairo_pattern_destroy (crp);
+}
+
+
+
 /* adapted from nautilus-gdk-extensions.c */
 static void
 interpolate_color (GdkColor *dest, gdouble ratio,
@@ -346,106 +400,125 @@ paint_stock_image (eazel_theme_data *theme_data,
 
 static void
 paint_outline (GdkWindow *window, GdkGC *gc, gboolean rounded,
-	       int x, int y, int width, int height)
+	       gdouble x, gdouble y, gdouble width, gdouble height)
 {
-    int corner = rounded ? 1 : 0;
+	gdouble radius = (rounded) ? 2.0 : 0.1;
+	GdkGCValues values;
+	cairo_t *cr;
 
-    /* left and top outermost */
-    gdk_draw_line (window, gc, x, y + corner,
-		   x, y + height - (corner + 1));
-    gdk_draw_line (window, gc, x + corner, y, x + width - (corner + 1), y);
+	cr = crux_begin_paint (window, NULL);
 
-    /* right and bottom outermost */
-    gdk_draw_line (window, gc, x + width - 1, y + corner,
-		   x + width - 1, y + height - (corner + 1));
-    gdk_draw_line (window, gc, x + corner, y + height - 1,
-		   x + width - (corner + 1), y + height - 1);
+	gdk_gc_get_values (gc, &values);
+	gdk_colormap_query_color (gdk_gc_get_colormap (gc), values.foreground.pixel, &values.foreground);
+	gdk_cairo_set_source_color (cr, &values.foreground);
+
+	x += 0.5; y += 0.5;
+	width -= 1.0; height -= 1.0;
+
+	cairo_move_to (cr, x + radius, y);
+	cairo_arc (cr, x + width - radius, y + radius, radius, M_PI * 1.5, M_PI * 2);
+	cairo_arc (cr, x + width - radius, y + height - radius, radius, 0, M_PI * 0.5);
+	cairo_arc (cr, x + radius, y + height-radius, radius, M_PI * 0.5, M_PI);
+	cairo_arc (cr, x + radius, y + radius, radius, M_PI, M_PI * 1.5);
+
+	cairo_stroke (cr);
+	cairo_destroy (cr);
 }
 
 static void
 paint_shadow (GdkWindow *window, GdkGC *a, GdkGC *b, GdkGC *c, GdkGC *d,
-	      gboolean rounded, int x, int y, int width, int height)
+	      gboolean rounded, gdouble x, gdouble y, gdouble width, gdouble height)
 {
-    int corner = rounded ? 1 : 0;
+	/* a: left/top, outer; b: left/top inner; c: right/bottom inner, d: right/bottom outer */
 
-    if (a != 0)
-    {
-	/* left and top outermost */
-	gdk_draw_line (window, a, x, y + corner,
-		       x, y + height - (corner + 1));
-	gdk_draw_line (window, a, x + corner, y, x + width - (corner + 1), y);
-    }
+	GdkGCValues values;
+	gdouble radius = (rounded) ? 2.0 : 0.1;
+	cairo_t * cr;
 
-    if (d != 0)
-    {
-	/* right and bottom outermost */
-	gdk_draw_line (window, d, x + width - 1, y + corner,
-		       x + width - 1, y + height - (corner + 1));
-	gdk_draw_line (window, d, x + corner, y + height - 1,
-		       x + width - (corner + 1), y + height - 1);
-    }
+	x += 0.5; y += 0.5;
+	width -= 1.0; height -= 1.0;
 
-    if (b != 0)
-    {
-	/* left and top inner */
-	gdk_draw_line (window, b, x + 1, y + 2, x + 1, y + height - 2);
-	gdk_draw_line (window, b, x + 1, y + 1, x + width - 2, y + 1);
-    }
+	cr = crux_begin_paint (window, NULL);
 
-    if (c != 0)
-    {
-	/* right and bottom outermost */
-	gdk_draw_line (window, c, x + width - 2, y + 1,
-		       x + width - 2, y + height - 2);
-	gdk_draw_line (window, c, x + 1, y + height - 2,
-		       x + width - 2, y + height - 2);
-    }
+	if (a != 0)
+	{
+		/* left and top outermost */
+		gdk_gc_get_values (a, &values);
+		gdk_colormap_query_color (gdk_gc_get_colormap (a), values.foreground.pixel, &values.foreground);
+		gdk_cairo_set_source_color (cr, &values.foreground);
+
+		cairo_arc (cr, x + radius, y + height - radius, radius, M_PI * 0.75, M_PI);
+		cairo_arc (cr, x + radius, y + radius, radius, M_PI, M_PI * 1.5);
+		cairo_arc (cr, x + width - radius, y + radius, radius, M_PI * 1.5, M_PI * 1.75);
+		cairo_stroke (cr);
+	}
+
+	if (d != 0)
+	{
+		/* right and bottom outermost */
+		gdk_gc_get_values (d, &values);
+		gdk_colormap_query_color (gdk_gc_get_colormap (d), values.foreground.pixel, &values.foreground);
+		gdk_cairo_set_source_color (cr, &values.foreground);
+
+		cairo_arc (cr, x + width - radius, y + radius, radius, M_PI * 1.75, 0);
+		cairo_arc (cr, x + width - radius, y + height - radius, radius, 0, M_PI * 0.5);
+		cairo_arc (cr, x + radius, y + height - radius, radius, M_PI * 0.5, M_PI * 0.75);
+		cairo_stroke (cr);
+	}
+
+
+	/* +-1 for inner lines, although this should probably be set to the pen width */
+	/* XXX: are these actually used anywhere usefully? */
+
+	if (b != 0)
+	{
+		/* left and top inner */
+		gdk_gc_get_values (b, &values);
+		gdk_colormap_query_color (gdk_gc_get_colormap (b), values.foreground.pixel, &values.foreground);
+		gdk_cairo_set_source_color (cr, &values.foreground);
+
+		cairo_arc (cr, x + radius + 1.0, y + height - radius - 1.0, radius, M_PI * 0.75, M_PI);
+		cairo_arc (cr, x + radius + 1.0, y + radius + 1.0, radius, M_PI, M_PI * 1.5);
+		cairo_arc (cr, x + width - radius - 1.0, y + radius + 1.0, radius, M_PI * 1.5, M_PI * 1.75);
+		cairo_stroke (cr);
+	}
+
+	if (c != 0)
+	{
+		/* right and bottom inner */
+		gdk_gc_get_values (c, &values);
+		gdk_colormap_query_color (gdk_gc_get_colormap (c), values.foreground.pixel, &values.foreground);
+		gdk_cairo_set_source_color (cr, &values.foreground);
+
+		cairo_arc (cr, x + width - radius - 1.0, y + radius + 1.0, radius, M_PI * 1.75, 0);
+		cairo_arc (cr, x + width - radius -1.0, y + height - radius - 1.0, radius, 0, M_PI * 0.5);
+		cairo_arc (cr, x + radius + 1.0, y + height - radius - 1.0, radius, M_PI * 0.5, M_PI * 1.25);
+		cairo_stroke (cr);
+	}
+
+	cairo_destroy (cr);
 }
 
 static void
 paint_entry_shadow (GdkWindow *window, GtkStyle *style,
 		    GtkStateType state_type,
-		    int x, int y, int width, int height)
+		    gdouble x, gdouble y, gdouble width, gdouble height)
 {
-    gdk_draw_rectangle (window, style->black_gc, FALSE,
-			x + 1, y + 1, width - 3, height - 3);
-
-    gdk_draw_line (window, style->dark_gc[state_type],
-		   x, y, x + width - 1, y);
-    gdk_draw_line (window, style->dark_gc[state_type],
-		   x, y, x, y + height - 1);
-
-    gdk_draw_line (window, style->white_gc,
-		   x + 1, y + height - 1, x + width - 1, y + height - 1);
-    gdk_draw_line (window, style->white_gc,
-		   x + width - 1, y + 1, x + width - 1, y + height - 1);
-
-    gdk_draw_line (window, style->mid_gc[state_type],
+	paint_shadow (window, style->dark_gc[state_type], style->black_gc, style->black_gc, style->white_gc, FALSE, x, y, width, height);
+	/*
+	TODO: Convert these two remaining lines to cairo
+	gdk_draw_line (window, style->mid_gc[state_type],
 		   x + 2, y + 2, x + width - 3, y + 2);
-    gdk_draw_line (window, style->mid_gc[state_type],
+	gdk_draw_line (window, style->mid_gc[state_type],
 		   x + 2, y + 2, x + 2, y + height - 3);
-
-    gdk_draw_line (window, style->white_gc,
-		   x + 2, y + height - 3, x + width - 3, y + height - 3);
-    gdk_draw_line (window, style->white_gc,
-		   x + width - 3, y + 2, x + width - 3, y + height - 3);
+	*/
 }
 
 static void
 paint_menuitem_shadow (GdkWindow *window, GtkStyle *style,
 		       int x, int y, int width, int height)
 {
-    gdk_draw_rectangle (window, style->black_gc, FALSE,
-			x + 2, y + 1, width - 5, height - 3);
-
-    gdk_draw_line (window, style->dark_gc[GTK_STATE_NORMAL],
-		   x + 1, y, x + width - 3, y);
-    gdk_draw_line (window, style->dark_gc[GTK_STATE_NORMAL],
-		   x + 1, y, x + 1, y + height - 2);
-    gdk_draw_line (window, style->white_gc,
-		   x + 2, y + height - 1, x + width - 2, y + height - 1);
-    gdk_draw_line (window, style->white_gc,
-		   x + width - 2, y + 1, x + width - 2, y + height - 1);
+	paint_shadow (window, style->dark_gc[GTK_STATE_NORMAL], style->black_gc, style->black_gc, style->white_gc, FALSE, x, y, width, height);
 }
 
 static void
@@ -453,7 +526,7 @@ paint_default_highlight (eazel_theme_data *theme_data,
 			 GdkColor *hi_color, GdkColor *bg_color,
 			 GdkWindow *window, GdkGC *gc, int x, int y)
 {
-    GdkColormap *sys_lut = gdk_drawable_get_colormap (GDK_DRAWABLE (window));
+    GdkColormap *sys_lut = gdk_colormap_get_system ();
     GdkGCValues old_values;
     GdkColor spectrum[6];
     int i;
@@ -583,7 +656,7 @@ paint_focus_box (eazel_theme_data *theme_data, GdkWindow *window,
 		 GdkGC *gc, gboolean rounded, gboolean rounded_inner,
 		 int thickness, int x, int y, int width, int height)
 {
-    GdkColormap *sys_lut = gdk_drawable_get_colormap (GDK_DRAWABLE (window));
+    GdkColormap *sys_lut = gdk_colormap_get_system ();
     GdkGCValues old_values;
     GdkColor color;
     gdk_gc_get_values (gc, &old_values);
@@ -603,7 +676,7 @@ paint_insensitive_box (eazel_theme_data *theme_data,
 		       GdkWindow *window, GdkGC *gc, gboolean rounded,
 		       int x, int y, int width, int height)
 {
-    GdkColormap *sys_lut = gdk_drawable_get_colormap (GDK_DRAWABLE (window));
+    GdkColormap *sys_lut = gdk_colormap_get_system ();
     GdkGCValues old_values;
     GdkColor color;
     gdk_gc_get_values (gc, &old_values);
@@ -863,8 +936,8 @@ draw_shadow (GtkStyle *style,
 
     outline = theme_data->outline_shadow;
 
-/*    if (widget != 0 && !GTK_WIDGET_IS_SENSITIVE (widget))
-	state_type = GTK_STATE_INSENSITIVE; XXX: REMOVED */
+    if (widget != 0 && !GTK_WIDGET_IS_SENSITIVE (widget))
+	state_type = GTK_STATE_INSENSITIVE;
 
     debug ("draw_shadow: detail=%s state=%d shadow=%d x=%d y=%d w=%d h=%d\n",
 	    detail, state_type, shadow_type, x, y, width, height);
@@ -1060,6 +1133,9 @@ draw_box (GtkStyle *style,
     eazel_theme_data *theme_data;
     gboolean set_bg = FALSE;
 
+	cairo_t * cr;
+	GdkGCValues values;
+
     g_return_if_fail (style != NULL);
     g_return_if_fail (window != NULL);
 
@@ -1093,6 +1169,9 @@ draw_box (GtkStyle *style,
       }
     }
 
+    if (widget != 0 && !GTK_WIDGET_IS_SENSITIVE (widget))
+	state_type = GTK_STATE_INSENSITIVE;
+
     debug ("draw_box: detail=%s state=%d shadow=%d x=%d y=%d w=%d h=%d\n",
 	    detail, state_type, shadow_type, x, y, width, height);
 
@@ -1164,7 +1243,7 @@ draw_box (GtkStyle *style,
 	    if (state_type != GTK_STATE_INSENSITIVE)
 	    {
 		gboolean focused;
-		focused = TRUE;
+		focused = 1;
 		paint_stock_image (theme_data,
 				   focused ? EAZEL_ENGINE_PROGRESS_BAR
 				   : EAZEL_ENGINE_PROGRESS_BAR_INACTIVE,
@@ -1244,40 +1323,26 @@ draw_box (GtkStyle *style,
 	    full.width = width;
 	    full.height = height;
 
-	   if (DETAIL ("menuitem"))
-	   {
-			if (state_type == GTK_STATE_INSENSITIVE) /* Catch for OpenOffice 2 */
-				return;
-			full.x +=3; full.y+=2;
-			full.width -= 6; full.height -= 4;
-			paint_menuitem_shadow (window, style, x, y, width, height);
-			eazel_engine_draw_gradient (window, style->bg_gc[state_type], &full,
-		                                &full, theme_data->gradients[state_type]);
-	   }
+	if (DETAIL ("menuitem"))
+	{
+		paint_menuitem_shadow (window, style, x, y, width, height);
 
-	    if (gradient != NULL && gradient->direction != GRADIENT_NONE)
-	    {
-		if (!set_bg)
-		{
-		    eazel_engine_draw_gradient (window,
-						style->bg_gc[state_type],
-						&full, &full, gradient);
-		}
-		else
-		{
-		    GdkRectangle dest;
-
-		    if (area != 0)
-			gdk_rectangle_intersect (&full, area, &dest);
-		    else
-			dest = full;
-		    eazel_engine_set_bg_gradient (window, gradient);
-		    gdk_window_clear_area (window, dest.x, dest.y,
-					   dest.width, dest.height);
-		}
-	    }
-	    else
-	    {
+		cr = crux_begin_paint (window, area);
+		gdk_gc_get_values (style->bg_gc[state_type], &values);
+		gdk_colormap_query_color (gdk_gc_get_colormap (style->bg_gc[state_type]), values.foreground.pixel, &values.foreground);
+		crux_paint_menuitem_gradient (cr, &values.foreground, x + 2, y + 2, width - 4, height - 4);
+		cairo_destroy (cr);
+	}
+	else if (gradient != NULL && gradient->direction != GRADIENT_NONE)
+	{
+		cr = crux_begin_paint (window, area);
+		gdk_gc_get_values (style->bg_gc[state_type], &values);
+		gdk_colormap_query_color (gdk_gc_get_colormap (style->bg_gc[state_type]), values.foreground.pixel, &values.foreground);
+		crux_paint_gradient (cr, &values.foreground, &full, gradient);
+		cairo_destroy (cr);
+	}
+	else
+	{
 		if (!set_bg)
 		{
 		    gdk_draw_rectangle (window, style->bg_gc[state_type], TRUE,
@@ -1294,7 +1359,7 @@ draw_box (GtkStyle *style,
 		    gdk_window_clear_area (window, dest.x, dest.y,
 					   dest.width, dest.height);
 		}
-	    }
+	}
 
 	    if (DETAIL ("button") && widget != 0
 		&& GTK_WIDGET_HAS_DEFAULT (widget))
@@ -1559,8 +1624,8 @@ draw_arrow (GtkStyle *style,
 	int window_width, window_height;
 	int tem_x, tem_y;
 
-/*	if (widget != 0 && !GTK_WIDGET_IS_SENSITIVE (widget))
-	    state_type = GTK_STATE_INSENSITIVE; XXX: REMOVED */
+	if (widget != 0 && !GTK_WIDGET_IS_SENSITIVE (widget))
+	    state_type = GTK_STATE_INSENSITIVE;
 
 	gdk_window_get_size (window, &window_width, &window_height);
 
@@ -1617,8 +1682,8 @@ draw_arrow (GtkStyle *style,
     }
     else
     {
-/*	if (widget != 0 && !GTK_WIDGET_IS_SENSITIVE (widget))
-	    state_type = GTK_STATE_INSENSITIVE; XXX: REMOVED */
+	if (widget != 0 && !GTK_WIDGET_IS_SENSITIVE (widget))
+	    state_type = GTK_STATE_INSENSITIVE;
 
 	paint_arrow (window, style->fg_gc[state_type],
 		     arrow_type, x, y, width, height);
@@ -1872,13 +1937,13 @@ paint_check (GtkStyle *style,
 	    active = GTK_TOGGLE_BUTTON (widget)->active;
 	if (widget != 0)
 	{
-	    /*state_type = GTK_WIDGET_STATE (widget); XXX: REMOVEd, FIXME */
+	    state_type = GTK_WIDGET_STATE (widget);
 	    /* XXX the widget gives us no way to tell between
 	       XXX checked, and checked-and-clicked states.. */
-/*	    if (active && state_type == GTK_STATE_ACTIVE)
+	    if (active && state_type == GTK_STATE_ACTIVE)
 		state_type = GTK_STATE_NORMAL;
 	    else if (!has_focus && !active && state_type == GTK_STATE_ACTIVE)
-		state_type = GTK_STATE_NORMAL;*/
+		state_type = GTK_STATE_NORMAL;
 	}
     }
 
@@ -2114,8 +2179,6 @@ draw_extension (GtkStyle *style,
 		gint y, gint width, gint height, GtkPositionType gap_side)
 {
     GdkRectangle rect;
-	GtkWidget* parent_widget;
-	gint relative_x;
 
     eazel_theme_data *theme_data;
 
@@ -2129,6 +2192,8 @@ draw_extension (GtkStyle *style,
 	    detail, state_type, shadow_type, x, y, width, height);
 
 	/* Get x relative to parent widget, not window */
+	GtkWidget* parent_widget;
+	gint relative_x;
 	if (widget != NULL)
 	{
 		parent_widget = gtk_widget_get_parent(widget);
@@ -2256,12 +2321,12 @@ draw_focus (GtkStyle *style,
 	{
 		if (area)
 			gdk_gc_set_clip_rectangle (style->black_gc, area);
-		/* if (DETAIL ("button"))
+		if (DETAIL ("button"))
 		{
-			x -= theme_data->focus_thickness; y -= theme_data->focus_thickness;
-			width += theme_data->focus_thickness * 2; height += theme_data->focus_thickness * 2;
+			//x -= theme_data->focus_thickness; y -= theme_data->focus_thickness;
+			//width += theme_data->focus_thickness * 2; height += theme_data->focus_thickness * 2;
 		}
-		else */ if (DETAIL ("text") || DETAIL ("entry"))
+		else if (DETAIL ("text") || DETAIL ("entry"))
 		{
 			rounded_inner = FALSE;
 		}
@@ -2316,12 +2381,14 @@ draw_slider (GtkStyle *style,
     if (area)
 	gdk_gc_set_clip_rectangle (style->black_gc, area);
 
-    focused = TRUE;
+    focused = (widget != 0);
 
     if (DETAIL ("slider")) {
 	{
 	    int thumb_x, thumb_y;
 
+	    focused = 1;
+
 	    /* XXX could be a gradient? */
 	    paint_stock_image (theme_data,
 			       width > height
@@ -2477,7 +2544,7 @@ crux_draw_style_class_init (GtkStyleClass *style_class)
   style_class->draw_diamond = draw_diamond;
   style_class->draw_string = draw_string;
   style_class->draw_box = draw_box;
-  /* style_class->draw_flat_box = draw_flat_box; */
+  //style_class->draw_flat_box = draw_flat_box;
   style_class->draw_check = draw_check;
   style_class->draw_option = draw_option;
   style_class->draw_tab = draw_tab;
